==> PyGithub-1.21.0.tar.gz: PyGithub-1.21.0/github/InputFileContent.py <==
# -*- coding: utf-8 -*-

############################ Copyrights and license ############################
#                                                                              #
# Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2012 Zearin <zearin@gonk.net>                                      #
# Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
#                                                                              #
# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
#                                                                              #
# PyGithub is free software: you can redistribute it and/or modify it under    #
# the terms of the GNU Lesser General Public License as published by the Free  #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# PyGithub is distributed in the hope that it will be useful, but WITHOUT ANY  #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS    #
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more #
# details.                                                                     #
#                                                                              #
# You should have received a copy of the GNU Lesser General Public License     #
# along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
#                                                                              #
################################################################################

import github.GithubObject


class InputFileContent(object):
    """
    """

    def __init__(self, content, new_name=github.GithubObject.NotSet):
        """
        :param content: string
        :param new_name: string
        """

        assert isinstance(content, (str, unicode)), content
        assert new_name is github.GithubObject.NotSet or isinstance(new_name, (str, unicode)), new_name
        self.__newName = new_name
        self.__content = content

    @property
    def _identity(self):
        identity = {
            "content": self.__content,
        }
        if self.__newName is not github.GithubObject.NotSet:
            identity["filename"] = self.__newName
        return identity

==> PyGithub-2.1.0.post0.tar.gz: PyGithub-2.1.0.post0/github/InputFileContent.py <==
############################ Copyrights and license ############################
#                                                                              #
# Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2012 Zearin <zearin@gonk.net>                                      #
# Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
#                                                                              #
# This file is part of PyGithub.                                               #
# http://pygithub.readthedocs.io/                                              #
#                                                                              #
# PyGithub is free software: you can redistribute it and/or modify it under    #
# the terms of the GNU Lesser General Public License as published by the Free  #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# PyGithub is distributed in the hope that it will be useful, but WITHOUT ANY  #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS    #
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more #
# details.                                                                     #
#                                                                              #
# You should have received a copy of the GNU Lesser General Public License     #
# along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
#                                                                              #
################################################################################


from __future__ import annotations

from typing import Any

from github.GithubObject import NotSet, Opt, is_defined, is_optional


class InputFileContent:
    """
    This class represents InputFileContents
    """

    def __init__(self, content: str, new_name: Opt[str] = NotSet):
        assert isinstance(content, str), content
        assert is_optional(new_name, str), new_name
        self.__newName: Opt[str] = new_name
        self.__content: str = content

    @property
    def _identity(self) -> dict[str, str]:
        identity: dict[str, Any] = {
            "content": self.__content,
        }
        if is_defined(self.__newName):
            identity["filename"] = self.__newName
        return identity
